@@ -1,3 +1,5 @@
+# encoding: utf-8
+
 import mimetypes
 import tempfile
 import csv
@@ -18,7 +20,7 @@ logger = logging.getLogger('collective.upgrade.pas')
 
 class Reconciler(object):
 
-    filename = 'reconcile_{}s.csv'
+    filename = 'reconcile_{0}s.csv'
 
     def __init__(self, context, principal_type):
         self.context = context
@@ -31,11 +33,11 @@ class Reconciler(object):
 
 class ExportReconciler(Reconciler):
 
-    fieldnames = ('Source Plugin ID',
-                  'Source ID',
-                  'Destination Plugin ID',
-                  'Destination ID',
-                  'Destination Duplicate IDs')
+    fieldnames = (b'Source Plugin ID',
+                  b'Source ID',
+                  b'Destination Plugin ID',
+                  b'Destination ID',
+                  b'Destination Duplicate IDs')
     user_properties = ('fullname', )
 
     def __init__(self, context, principal_type,
@@ -46,7 +48,7 @@ class ExportReconciler(Reconciler):
         self.plugins = self.acl_users._getOb('plugins')
 
         self.get_rows = getattr(
-            self, 'get_{}_rows'.format(self.principal_type))
+            self, 'get_{0}_rows'.format(self.principal_type))
 
         if principal_type == 'user':
             if not dest_users_plugin:
@@ -92,7 +94,7 @@ class ExportReconciler(Reconciler):
             self.plugins.deactivatePlugin(
                 IUserEnumerationPlugin, self.dest_users.getId())
             if self.dest_properties.getId() in self.plugins.listPluginIds(
-                IUserEnumerationPlugin):
+                    IUserEnumerationPlugin):
                 self.plugins.deactivatePlugin(
                     IUserEnumerationPlugin, self.dest_properties.getId())
 
@@ -217,7 +219,7 @@ class ImportReconciler(Reconciler):
         self.acl_users = getToolByName(self.site, 'acl_users')
         self.plugins = self.acl_users._getOb('plugins')
 
-        getPrincipalById = getattr(self.acl_users, 'get{}ById'.format(
+        getPrincipalById = getattr(self.acl_users, 'get{0}ById'.format(
             self.principal_type.capitalize()))
         rows = {}
         for row in reader:
@@ -259,7 +261,7 @@ class ImportReconciler(Reconciler):
             for source_id, dest_id in rows.iteritems():
                 # ownership
                 if (acl_users_path, source_id) == (
-                    userdb_path, user_id):
+                        userdb_path, user_id):
                     logger.info('Changing %r owner from %r to %r',
                                 obj, source_id, dest_id)
                     dest_principal = getPrincipalById(dest_id)
