@@ -1,3 +1,6 @@
+# encoding: utf-8
+
+from zope import interface
 from zope import component
 
 from Products.CMFCore.utils import getToolByName
@@ -9,8 +12,31 @@ from collective.upgrade import upgrader
 _marker = object()
 
 
+@interface.implementer(plone_ifaces.INonInstallable)
+class HiddenProfiles(object):
+    """
+    Exclude utility or upgrade profiles on the Plone add-on control panel.
+    """
+
+    def getNonInstallableProducts(self):  # pragma: no cover
+        """
+        No general packages all of whose profiles to exclude.
+        """
+        return []
+
+    def getNonInstallableProfiles(self):  # pragma: no cover
+        """
+        Exclude utility or upgrade profiles on the Plone add-on control panel.
+        """
+        return [
+            u"collective.upgrade:blank",
+        ]
+
+
+@component.adapter(plone_ifaces.IPloneSiteRoot)
 class PloneUpgrader(upgrader.PortalUpgrader):
-    component.adapts(plone_ifaces.IPloneSiteRoot)
+
+    RESOURCE_TOOLS = {'portal_css', 'portal_javascripts', 'portal_kss'}
 
     def upgrade(self, **kw):
         # May fix the profile version
@@ -19,10 +45,16 @@ class PloneUpgrader(upgrader.PortalUpgrader):
 
         result = super(PloneUpgrader, self).upgrade(**kw)
 
-        getToolByName(self.context, 'portal_css').cookResources()
-        getToolByName(self.context, 'portal_javascripts').cookResources()
-        getToolByName(self.context, 'portal_kss').cookResources()
-        self.log('Refreshed resource registries for {0}'.format(self.context))
+        # BBB Support for Plone < 5.2
+        resource_tools_exist = False
+        for resource_tool_id in self.RESOURCE_TOOLS:
+            resource_tool = getToolByName(self.context, resource_tool_id, None)
+            if resource_tool is not None:
+                resource_tool.cookResources()
+                resource_tools_exist = True
+        if resource_tools_exist:
+            self.log('Refreshed resource registries for {0}'.format(
+                self.context))
 
         return result
 
@@ -43,7 +75,7 @@ class PloneUpgrader(upgrader.PortalUpgrader):
                 if orig is _marker:
                     properties.site_properties._delPropValue(
                         enable_link_integrity_checks)
-                else:
+                elif hasattr(properties, 'site_properties'):
                     properties.site_properties.manage_changeProperties(
                         enable_link_integrity_checks=orig)
 
