@@ -1,6 +1,10 @@
+# encoding: utf-8
+
 import logging
 import re
 
+import transaction
+
 from Acquisition import aq_base, aq_parent
 from Products.PluginIndexes.FieldIndex import FieldIndex
 from Products.ZCatalog.ProgressHandler import ZLogHandler
@@ -8,7 +12,6 @@ from Products.ZCatalog.ProgressHandler import ZLogHandler
 from Products.CMFCore.utils import getToolByName
 
 from plone.uuid import interfaces as uuid_ifaces
-from Products.Archetypes import interfaces as at_ifaces
 
 from collective.upgrade import utils
 
@@ -69,6 +72,7 @@ def uninstallAddOns(context, addons=None):
     uninstalled.
     """
     qi = getToolByName(context, 'portal_quickinstaller')
+    setup = getToolByName(context, 'portal_setup')
     for product in qi.listInstallableProducts(skipInstalled=False):
         addon = product['id']
         if addons is not None:
@@ -81,7 +85,6 @@ def uninstallAddOns(context, addons=None):
         install_profiles = qi.getInstallProfiles(addon)
         uninstall_profiles = [profile for profile in install_profiles
                               if profile.split(':', 1) == 'uninstall']
-        setup = getToolByName(context, 'portal_setup')
         if uninstall_profiles:
             profile = uninstall_profiles[0]
             logger.info(
@@ -246,6 +249,8 @@ class ReferenceTargetCleaner(utils.Upgrader):
             self.context, search_sub=1, apply_func=self.upgradeObj)
 
     def upgradeObj(self, obj, path=None):
+        from Products.Archetypes import interfaces as at_ifaces
+
         if not at_ifaces.IReferenceable.providedBy(obj):
             return
         for ref in self.ref_catalog.getReferences(obj):
@@ -260,3 +265,82 @@ def cleanupMissingReferenceTargets(context):
     url = getToolByName(context, 'portal_url')
     upgrader = ReferenceTargetCleaner(url.getPortalObject())
     upgrader.upgrade()
+
+
+def pack_zodb(context, t=None, days=0):
+    """
+    Pack the database after upgrades to conserve disk space.
+    """
+    utils.transaction_note(
+        context, note='Committing changes prior to packing the ZODB')
+    transaction.commit()
+    db = context._p_jar.db()
+    db.pack(t, days)
+
+
+def cookResourceRegisties(context, ids=None):
+    """
+    Cook all JavaScript and CSS resources in all resource registries.
+
+    This can address the issue where sometimes the resource registries viewlet
+    fails to render correctly.
+    """
+    url = getToolByName(context, 'portal_url')
+    portal = url.getPortalObject()
+    for obj in portal.objectValues():
+        if hasattr(obj, 'cookResources'):
+            obj.cookResources()
+
+
+def resetProfiles(context, extension_profiles=None):
+    """
+    Reset the site to its initial profile state.
+
+    Re-apply the base GenericSetup profile and run all import steps from
+    extension profiles.  Example ZCML for a full reset:
+
+      <genericsetup:upgradeSteps
+          profile="foo.policy:default"
+          source="001" destination="002">
+          <genericsetup:upgradeDepends
+              title="Blank the site"
+              description=
+              "Blank all import steps prior to re-setting the site."
+              import_profile="collective.upgrade:blank" purge="true" />
+          <genericsetup:upgradeStep
+              title="Reset the site"
+              description="Reset to the base profile and default extensions"
+              handler="collective.upgrade.steps.resetProfiles" />
+          <genericsetup:upgradeDepends
+              title="Import initial extension profile"
+              description=
+              "Re-import the initial extension profile after resetting"
+              import_profile="foo.policy:initial" run_deps="true" />
+          <genericsetup:upgradeDepends
+              title="Import policy extension profile"
+              description=
+              "Re-import the policy extension profile after resetting"
+              import_profile="foo.policy:default" run_deps="true" />
+          <genericsetup:upgradeStep
+              title="Update the catalog"
+              description="Update the catalog after resetting the site."
+              handler="collective.upgrade.steps.catalogReindex" />
+      </genericsetup:upgradeSteps>
+    """
+    if extension_profiles is None:
+        url = getToolByName(context, 'portal_url')
+        portal = url.getPortalObject()
+        form = portal.restrictedTraverse('@@plone-addsite')
+        extension_profiles = [
+            info['id'] for info in form.profiles()['extensions']
+            if info.get('selected') == 'selected']
+
+    setup = getToolByName(context, 'portal_setup')
+
+    base_profile = setup.getBaselineContextID()
+    logger.info('Importing the %r base profile', base_profile)
+    setup.runAllImportStepsFromProfile(base_profile, purge_old=False)
+
+    for extension_profile in extension_profiles:
+        logger.info('Importing the %r extension profile', extension_profile)
+        setup.runAllImportStepsFromProfile('profile-%s' % extension_profile)
