@@ -1,6 +1,9 @@
-import operator
+# encoding: utf-8
 
 from zope.component import hooks
+from zope.event import notify
+from zope.globalrequest import setRequest
+from zope.traversing.interfaces import BeforeTraverseEvent
 
 from Products.CMFCore.utils import getToolByName
 from Products.GenericSetup.upgrade import _upgrade_registry
@@ -10,19 +13,36 @@ from collective.upgrade import utils
 
 class PortalUpgrader(utils.Upgrader):
 
-    def upgrade(self, **kw):
+    def upgrade(
+            self, upgrade_portal=True,
+            upgrade_all_profiles=True, upgrade_profiles=(), **kw):
         hooks.setSite(self.context)
+        setRequest(self.context.REQUEST)
+        # initialize portal_skins
+        self.context.setupCurrentSkin(self.context.REQUEST)
+        # setup language for plone 4: see https://docs.plone.org/manage/upgrading/version_specific_migration/p4x_to_p5x_upgrade.html#portal-languages-is-now-a-utility  # noqa
+        if getattr(self.context, 'portal_languages', None):
+            self.context.portal_languages(self.context, self.context.REQUEST)
         self.setup = getToolByName(self.context, 'portal_setup')
         self.log('Upgrading {0}'.format(self.context))
+        # setup BrowserLayer, see: https://dev.plone.org/ticket/11673
+        notify(BeforeTraverseEvent(self.context, self.context.REQUEST))
 
-        # Do the baseline profile upgrade first
         baseline = self.setup.getBaselineContextID()
         prof_type, profile_id = baseline.split('-', 1)
         self.base_profile = profile_id
-        self.upgradeProfile(profile_id, **kw)
+        if upgrade_portal:
+            # Do the baseline profile upgrade first
+            self.upgradeProfile(profile_id, **kw)
 
         # Upgrade extension profiles
-        self.upgradeExtensions(**kw)
+        if upgrade_all_profiles:
+            if upgrade_profiles:
+                raise ValueError(
+                    'upgrade_profiles conflicts with upgrade_all_profiles')
+            upgrade_profiles = self.setup.listProfilesWithPendingUpgrades()
+        if upgrade_profiles:
+            self.upgradeExtensions(upgrade_profiles, **kw)
 
         self.log('Upgraded {0}'.format(self.context))
 
@@ -42,12 +62,12 @@ class PortalUpgrader(utils.Upgrader):
         all_upgrades = list(self.flattenUpgrades(profile_id))
         if not all_upgrades:
             return all_upgrades
+        dest = all_upgrades[0]['dest']
         upgrades = []
-        dest = max(
-            all_upgrades, key=operator.itemgetter('proposed', 'dest'))['dest']
         for info in all_upgrades:
-            if info['dest'] <= dest:
-                upgrades.append(info)
+            if info['dest'] != dest:
+                break
+            upgrades.append(info)
         return upgrades
 
     def flattenUpgrades(self, profile_id):
@@ -87,8 +107,8 @@ class PortalUpgrader(utils.Upgrader):
         self.commit("Upgraded profile %r to %r" %
                     (profile_id, '.'.join(step.dest)))
 
-    def upgradeExtensions(self, **kw):
-        for profile_id in self.setup.listProfilesWithUpgrades():
+    def upgradeExtensions(self, profile_ids, **kw):
+        for profile_id in profile_ids:
             if profile_id == self.base_profile:
                 continue
             if self.isProfileInstalled(profile_id):
